## Image detection

### Datasets

In the image recognition experiments, we used two different datasets: the *KITTI* dataset and the *German Traffic Signs Detection* (GTSDB) dataset. The following sections explain details of both datasets.

*KITTI dataset*:

The KITTI dataset is a widely used collection of urban and rural traffic images released by Karlsruhe Institute of Technology, in Germany. The training dataset contains 7,481 color image files and text files with label annotations and data about the 2D bounding boxes. The dataset is composed by 8 different classes ('Car', 'Van', 'Truck', 'Pedestrian', 'Person (sitting)', 'Cyclist', 'Tram' and 'Misc'), but it is heavily imbalanced in favour of 'Car' and 'Pedestrian' classes - only these two categories were considered in the original KITTI contest \cite{geiger2013vision}. The test dataset contains 7,518 images, but does not have the labels. For this reason, we decided to use the original training images for training and testing purposes in our experiments. To do this, we divided the original training dataset into new training and test sets, using a proportion of 80% of the images for training and 20% for test. The images were randomly split, without considering any kind of data balancing strategy. As result, the full dataset available for our detection models contained 5,985 images for training and 1,496 images for testing. In our work, this dataset was used with detection algorithms.

*German Traffic Signs Detection (GTSDB) dataset*:

The German Traffic Sign Detection Benchmark (GTSDB) dataset was developed provided by the Institute of Neuroinformatic of the Ruhr-Universität Bochum in 2013. It contains 900 images (600 for training and 300 for testing) divided into three classes. In this dataset, both training and testing set contain annotations of labels and 2D bounding boxes. Each image contain zero to six traffic signs, but some signs may not belong to the annotated classes.

### Data preparation

For both datasets, we converted the raw images into TFRecords format, TensorFlow's own binary storage format. This file type is optimized for TensorFlow data ingestion, once it can be more efficiently read by the algorithm. Also it occupies less space on disk \cite{them}, what was important in our use-case - the complete KITTI dataset occupied 12.9Gb on disk. Only for GTSDB, we performed some data augmentation procedures, given that the dataset was too small. In this case, we generated 1,000 new training images out from the original dataset, changing the brightness and sharpness of the images. The Table \ref{tab:kitti} shows the final complete size of KITTI and GTSDB datasets after data preparation.

### Model

The image detection model setup consisted of a combination of a *ResNet* classifier and a *Faster R-CNN*. *ResNet* stands for deep Residual Network, a type of Deep Learning that usually has less layers than other algorithms. Its development started after the observation that adding more layers to a Deep Learning model (in other words, making the model deeper) did not improve the performance of a model. In some cases, the performance decreased when adding more layers \cite{science}. In a Residual Network, the residuals of layers that already have optimal results are not mapped again. It allows the creation of shortcut connections, which add their outputs to stacked layers, without the addition of extra parameters or computational complexity \cite{he2016deep}. *Faster R-CNN* stands for Faster Region-based Convolutional Neural Networks, and are an evolutional of other models (R-CNN and Fast R-CNN). It has a complex architecture, composed by several moving parts \cite{blog}. In short, it constructs a unified model composed of RPN (region proposal network) and fast R-CNN with shared convolutional feature layers \cite{ren2015faster}.

As classifiers, different versions of Resnet were used. At first, Resnet 101 pre-trained on the COCO dataset was re-trained only for the two classes 'car' and 'pedestration' on the KITTI subsets. After that, the same setup was tested on augmented GTSDB dataset. As last step, we used a Resnet 50 pre-trained on Imagenet was for 'car' and 'pedestrian' re-training on Kitti. For the training process the object detection API scripts were used. 
