# Introduction

Recognizing and classifying images and videos is one of the most important challenges in the field of computer vision. Recently, models based on Deep Learning have shown an outstanding performance, compared to other algorithms, with several models being proposed \cite{donahue2015long}. Until the adoption of modern Artificial Intelligence models, the construction of pattern-recognition systems was based on  tailor-made solutions, with a huge effort in engineering and feature extraction to translate raw data to machine language. Deep Learning helps to solve this problem, as this technique has proven to achieve good results to discover complex structures in high-dimensional data. Figure \ref{919908} shows how Deep Learning accuracy has improved over past years, according to ImageNet Large Scale Visual Recognition Competition (ILSVRC) winners. In 2016, the winner model (based on Deep Learning) showed a better performance than a human \cite{Recker2017}. It is important to note that Deep Learning potential is being explored not only to image recognition, but also on predicting the activity of potential drug molecules, analysing particle accelerator data, reconstructing brain circuits, and predicting the effects of mutations in non-codiing DNA \cite{lecun2015deep}.

Driving is a very complicated task. Specially in city traffic, there are several events happening at the same time to which the driver must identify, pay attention and decide how to react to. Given the complexity of this task, it is not feasible to write programs that could handle the infinite number of things that can happen. With Artificial Intelligence, it is possible to train the car on how to understand what happens in the environment and what is the right behaviour to take to safely navigate. In this activity, image recognition is a crucial factor for autonomous driving. An autonomous vehicle needs to accurately detect cars, pedestrians, cyclists, road signs, and other objects in realtime in order to make the right control decisions that ensure safety. Although different carmakers can adopt different combinations of perception sensors, an image based object detection seems to be present in all modern solutions. \cite{wu2017squeezedet}

In the process of training Deep Learning models, one of the most important factors to increase the performance is to implement advanced statistical methods, which are backed with massive training datasets \cite{zhu2012we}. So, the lack of large datasets can limit further advancements of Deep Learning algorithms. In this direction, it is crucial to build large well annotated datasets to foster image recognition development \cite{hoo2016deep}.

This report presents the final results for the course DCAITI, project *Impact of Large Datasets on Classification Performance in Deep Learning*. In this project we were asked to analyze the performance of different Deep Learning Networks on image recognition and image classification. Our research goal was to identify what is the relationship between the amount of training data and the accuracy of image classifiers. For image detection, we implemented a pre-trained combination of a ResNet with a Fastr R-CN algorithm. This setup was trained and tested using two different traffic signs datasets, KITTI and German Traffic Signs Detection Benchmark. For the classification part, we implemented and evaluated a ResNet architecture. For this setup, we used the German Traffic Sign Recognition Benchmark (GTSRB) for training and test purposes. All models were trained using different training sizes, ranging from 5% to 100% of the original training set.

This paper is structured as follows: Section II describes the development and implementation of our solution. Section III shows the results of our approach and the challenges faced during the process, and in section IV we provide our conclusions and suggestions for future works.
